@@ -25,16 +25,17 @@ BASE_ON_SERVER = ''
 
 # Don't recurse into directories named like this:
 BLACKLIST = [
+    '.svn',
     '.attic',
     ]
 
 # If you see these, there won't be a usable tag deeper down, so just
 # stop looking in this directory.
 STOP_INDICATORS = [
-    'src',
-    'setup.py',
-    'version.txt',
-    'buildout.cfg',
+    #'src',
+    #'setup.py',
+    #'version.txt',
+    #'buildout.cfg',
     ]
 
 # Name of the output file. Used if you don't pass along a specific one
